# sagar

[![Build Status](https://travis-ci.org/scut-ccmp/sagar.svg?branch=master)](https://travis-ci.org/scut-ccmp/sagar)
[![codecov](https://codecov.io/gh/scut-ccmp/sagar/branch/master/graph/badge.svg)](https://codecov.io/gh/scut-ccmp/sagar)
[![Documentation Status](https://readthedocs.org/projects/sagar/badge/?version=latest)](https://sagar.readthedocs.io/)
[![MIT Licence](https://badges.frapsoft.com/os/mit/mit.svg?v=103)](https://opensource.org/licenses/mit-license.php)
[![Open Source Love](https://badges.frapsoft.com/os/v1/open-source.svg?v=103)](https://github.com/ellerbrock/open-source-badges/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/ansicolortags.svg)](https://pypi.python.org/pypi/ansicolortags/)

## Introduction
sagar is short for (S)Tructures of (A)lloys (G)eneration (A)nd (R)ecognition.

It is a library with some uitils to deal grid site
 structures.
